==> LL_utils-4.1.1.4-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_daemons.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)24 1.10 src/ll/config_editor/cgi-bin/pull_down_tab_panel_daemons.pl, ll.config, ll_rrur2, rrur21042a 1/2/10 03:57:42\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(0);
					
my @normal_tables_by_nodeID = ();

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
# subpanel=tab_panel_daemons&id=10
if(/subpanel=(.+)&id=(\d+)&name=(.*)/)
{
	my $subpanel = $1;
	if($subpanel eq "tab_panel_daemons")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_daemons"}->[0]};
	}
	elsif($subpanel eq "tab_panel_cm")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_cm"}->[0]};
	}
	elsif($subpanel eq "tab_panel_resmgr")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_resmgr"}->[0]};
	}
	elsif($subpanel eq "tab_panel_regmgr")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_regmgr"}->[0]};
	}
	elsif($subpanel eq "tab_panel_master")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_master"}->[0]};
	}
	elsif($subpanel eq "tab_panel_startd")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_startd"}->[0]};
	}
	elsif($subpanel eq "tab_panel_starter")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_starter"}->[0]};
	}
	elsif($subpanel eq "tab_panel_schedd")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_schedd"}->[0]};
	}
	elsif($subpanel eq "tab_panel_kbdd")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_kbdd"}->[0]};
	}
	else
	{
		my $json_str_err = "Content-type: text/html\n\n"."Error: Unknown sub panel name.";
		print $json_str_err;
		exit 1;
	}
	
	my $json_str_0 = "Content-type: text/html\n\n";	
	my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
	if(!defined($dbh))
	{
		my $json_str_err = $json_str_0."Error:".DBI->errstr;
		print $json_str_err;
		exit 1;
	}
	my $nodeID = $2;
	my $option_name = $3;
	
	my $json_str = $json_str_0."[";
	my $sth;

	# Get default node id
	my $default_node_id = undef;
	$default_node_id = get_default_id_by_primary_key($dbh,"nodeID","clusterID","TLL_Nodelist","hostname",$nodeID);

	# Get default values
	if(defined($default_node_id))
	{
		my $is_default = 0;
		if($default_node_id == $nodeID) { $is_default = 1; }
		$json_str .= get_default_json_str($dbh,$subpanel,"nodeID",$default_node_id,$is_default);
	}
	
	foreach my $table (@normal_tables_by_nodeID)
	{
		my $sql_str="select * from ".$table." where nodeID=".$nodeID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		my $ary_ref = $sth->fetchrow_arrayref;
		my $i = 0;
		$json_str .= "{type:'normal',id:'".$table."-id"."',value:'".$nodeID."'},";
		if(exists $ary_ref->[$i])
		{
		    for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
		    {
				$json_str .= "{type:'normal',id:'".$table."-".$sth->{NAME}->[$i]."',value:'".$ary_ref->[$i]."'},";
		    }
		}
	}

	$json_str =~ s/,$//g;
	$json_str .= "]";
	$sth->finish();
	print $json_str;
	$dbh->disconnect();

}

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_daemons.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)24 1.11 src/ll/config_editor/cgi-bin/pull_down_tab_panel_daemons.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:31:42\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(0);
					
my @normal_tables_by_nodeID = ();

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
# subpanel=tab_panel_daemons&id=10
if(/subpanel=(.+)&id=(\d+)&name=(.*)/)
{
	my $subpanel = $1;
	if($subpanel eq "tab_panel_daemons")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_daemons"}->[0]};
	}
	elsif($subpanel eq "tab_panel_cm")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_cm"}->[0]};
	}
	elsif($subpanel eq "tab_panel_resmgr")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_resmgr"}->[0]};
	}
	elsif($subpanel eq "tab_panel_regmgr")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_regmgr"}->[0]};
	}
	elsif($subpanel eq "tab_panel_master")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_master"}->[0]};
	}
	elsif($subpanel eq "tab_panel_startd")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_startd"}->[0]};
	}
	elsif($subpanel eq "tab_panel_starter")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_starter"}->[0]};
	}
	elsif($subpanel eq "tab_panel_schedd")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_schedd"}->[0]};
	}
	elsif($subpanel eq "tab_panel_kbdd")
	{
		@normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_kbdd"}->[0]};
	}
	else
	{
		my $json_str_err = "Content-type: text/html\n\n"."Error: Unknown sub panel name.";
		print $json_str_err;
		exit 1;
	}
	
	my $json_str_0 = "Content-type: text/html\n\n";	
	my $dbh = get_dbh(0);
	if(!defined($dbh))
	{
		error_and_exit($dbh->errstr);
	}
	my $nodeID = $2;
	my $option_name = $3;
	
	my $json_str = $json_str_0."[";
	my $sth;

	# Get default node id
	my $default_node_id = undef;
	$default_node_id = get_default_id_by_primary_key($dbh,"nodeID","clusterID","TLL_Nodelist","hostname",$nodeID);

	# Get default values
	if(defined($default_node_id))
	{
		my $is_default = 0;
		if($default_node_id == $nodeID) { $is_default = 1; }
		$json_str .= get_default_json_str($dbh,$subpanel,"nodeID",$default_node_id,$is_default);
	}
	
	foreach my $table (@normal_tables_by_nodeID)
	{
		my $sql_str="select * from ".$table." where nodeID=".$nodeID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		my $ary_ref = $sth->fetchrow_arrayref;
		my $i = 0;
		$json_str .= "{type:'normal',id:'".$table."-id"."',value:'".$nodeID."'},";
		if(exists $ary_ref->[$i])
		{
		    for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
		    {
				$json_str .= "{type:'normal',id:'".$table."-".$sth->{NAME}->[$i]."',value:'".$ary_ref->[$i]."'},";
		    }
		}
	}

	$json_str =~ s/,$//g;
	$json_str .= "]";
	$sth->finish();
	print $json_str;
	$dbh->disconnect();

}
